@@ -5,8 +5,8 @@ $self = {
                       'Cairo',
                       'Glib'
                     ],
-          'inc' => '-I/usr/include/pango-1.0 -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include -I./build -I/usr/include/cairo -I/usr/include/pango-1.0 -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include -I/usr/include/freetype2 -I/usr/include/pixman-1 -I/usr/include/uuid -I/usr/include/harfbuzz -I/usr/include/libpng16',
-          'libs' => '-lpango-1.0 -lgobject-2.0 -lglib-2.0 -lintl -lpangocairo-1.0 -lpango-1.0 -l:libcairo.dll.a -lgobject-2.0 -lglib-2.0 -lintl',
+          'inc' => '-I/usr/include/pango-1.0 -I/usr/include/harfbuzz -pthread -I/usr/include/fribidi -I/usr/include/cairo -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include -I/usr/include/pixman-1 -I/usr/include/freetype2 -I/usr/include/libpng16 -I./build -I/usr/include/pango-1.0 -I/usr/include/cairo -I/usr/include/pixman-1 -pthread -I/usr/include/fribidi -I/usr/include/harfbuzz -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include -I/usr/include/freetype2 -I/usr/include/libpng16',
+          'libs' => '-lpango-1.0 -lgobject-2.0 -lglib-2.0 -lintl -lharfbuzz -lpangocairo-1.0 -lpango-1.0 -lgobject-2.0 -lglib-2.0 -lintl -lharfbuzz -l:libcairo.dll.a',
           'typemaps' => [
                           'pango-perl.typemap',
                           'pango.typemap'
